{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
    {{ block.super }}

    {% if not is_popup %}
        <p>{% trans "First, enter a username and password. Then, you'll be able to edit more user options." %}</p>
    {% else %}
        <p>{% trans "Enter a username and password." %}</p>
    {% endif %}
{% endblock %}
