
{% extends 'admin/base_site.html' %}

{% load i18n %}


{% block extrahead %}
    {{ block.super }}
    <script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
    {{ form.media }}
{% endblock %}


{% block content %}
    <form method="post">
        {% csrf_token %}

        <p>
            {% trans 'Items count' %}
            ({{ items.count }}):
        </p>

        <div>
            {{ form }}
        </div>

        <hr />

        <input type="hidden" name="action" value="{{ action_name }}" />
        <input type="submit" class="btn btn-success" name="apply" value="{% trans 'Apply' %}" />
    </form>
{% endblock %}
